@@ -28,25 +28,17 @@
 #endif
 #include "dialog.h"
 
-/*
-  somewhat ugly (those *** :) so I feel like I may comment
-  as first argument it takes poiter to pointer on Dialog struct
-  which MUST contains GtkDialog * as first field
-
-  it is bassicaly the same trick as used in GtkObject's
-*/
-
 void
-run_dialog (GtkDialog ***dialog, GtkHTML *html, GtkHTMLControlData *cd, DialogCtor ctor, const gchar *title)
+run_dialog (GtkDialog **dialog, GtkHTML *html, GtkHTMLControlData *cd, DialogCtor ctor, const gchar *title)
 {
-	if (*dialog) {
-		gtk_window_set_title (GTK_WINDOW (**dialog), title);
-		gtk_widget_show (GTK_WIDGET (**dialog));
-		gdk_window_raise (GTK_WIDGET (**dialog)->window);
+	if (dialog) {
+		gtk_window_set_title (GTK_WINDOW (*dialog), title);
+		gtk_widget_show (GTK_WIDGET (*dialog));
+		gdk_window_raise (GTK_WIDGET (*dialog)->window);
 	} else {
-		*dialog = ctor (html, cd);
-		gtk_window_set_title (GTK_WINDOW (**dialog), title);
-		gtk_widget_show (GTK_WIDGET (**dialog));
+		dialog = ctor (html, cd);
+		gtk_window_set_title (GTK_WINDOW (*dialog), title);
+		gtk_widget_show (GTK_WIDGET (*dialog));
 	}
-	gtk_dialog_run (**dialog);
+	gtk_dialog_run (*dialog);
 }
